#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
Plug-in to open GIMP's vectors in 'Inkscape'. Version 0.3 for Linux and Windows.
Tested with GIMP-2.8.16 and Python-2.7.11 on Linux.

License:
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; version 3 of the License.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
The GNU Public License is available at
http://www.gnu.org/copyleft/gpl.html
'''

#import shlex
import sys, os, gettext
import gtk
import subprocess as sub


### global variables ###########################################################

whoiam = os.path.abspath(sys.argv[0])

# if not launch within GIMP
def mssgBox(mess):
    flag = gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT
    msgBox = gtk.MessageDialog(None, flag, gtk.MESSAGE_WARNING, gtk.BUTTONS_OK, mess)
    msgBox.run()
    msgBox.destroy()

try:
    from gimpfu import *
except ImportError:
    print("Note: GIMP is needed, '%s' is a plug-in for it.\n"%whoiam)
    # launch from GUI? use mssgBox(text)
    mssgBox("Note: GIMP is needed, '%s' is a plug-in for it.\n"%whoiam)
    sys.exit(1)

# for locale characters in windows file system
def sys_file(f_name):
    sys_encoded = sys.getfilesystemencoding()
    if os.name == 'nt': coded = f_name.encode(sys_encoded)
    else: coded = f_name
    return(coded)

# initialize internationalisation in a user-locale
locale_directory = os.path.join(os.path.dirname(whoiam), 'locale')
gettext.install( "Gimp_to_Reshade", locale_directory, unicode=True )


### main function ##############################################################

def open_file_in_reshade(image, layer, ink, outputFolder, format, schel, resize, rem):

    if os.access(sys_file(outputFolder), os.W_OK):
        gimp.progress_init(_("Zapisuję w '") + outputFolder + os.sep + layer.name)
    else:
        gimp.message(_("ERROR: folder '%s' isn't writable, plug-in has terminated.")%outputFolder)
        return
    if ink.find('reshade') == -1 : return
	
    if format=="png":
		xchange_utf = outputFolder + os.sep + layer.name + ".png"
		gimp.pdb.file_png_save(image, layer, xchange_utf, xchange_utf, 1, 1, 1, 0, 0, 1, 0, run_mode=RUN_INTERACTIVE)
    if format=="jpg":
		xchange_utf = outputFolder + os.sep + layer.name + ".jpg"
		gimp.pdb.file_jpeg_save(image, layer, xchange_utf, xchange_utf, 1, 0, 0, 0, 1, 0, 1, 0, 0, run_mode=RUN_INTERACTIVE)		
    if format=="tif":
		xchange_utf = outputFolder + os.sep + layer.name + ".tif"
		gimp.pdb.file_tiff_save(image, layer, xchange_utf, xchange_utf, 0, run_mode=RUN_INTERACTIVE)
	
    xchange_sys = sys_file(xchange_utf) # for Python, Win file system not 'utf-8'
    p = sub.Popen([ink, xchange_sys], stdin=sub.PIPE, stdout=sub.PIPE, stderr=sub.STDOUT)
    child_output, child_error = p.communicate()

    if schel:
		newlayer = pdb.gimp_file_load_layer(image, xchange_utf)
		image.add_layer(newlayer,-1)
    if format=="png":		
		gimp.pdb.file_png_load(xchange_utf, layer.name, run_mode=RUN_NONINTERACTIVE)
    if format=="jpg":
		gimp.pdb.file_jpeg_load(xchange_utf, layer.name, run_mode=RUN_NONINTERACTIVE)
    if format=="tif":		
		gimp.pdb.file_tiff_load(xchange_utf, layer.name, run_mode=RUN_NONINTERACTIVE)		
    if resize:		
		pdb.gimp_image_resize_to_layers(image)
				
    # cleanup temp file?
    if rem:
        os.remove(xchange_sys)
    pdb.gimp_displays_flush()
    gimp.progress_init(_("Plug-in end!"))		

### GIMP registring & UI #######################################################

register(
    "open-in-reshade",
    _("\n            Ten plugin otwiera aktywną warstwę w Reshade\n")\
    +_("-------------------------Instrukcja:--------------------------\n")\
    +_("W Reshade: po zmianie rozmiaru nadpisz otwarty plik i zamknij program.\nWtedy wrócisz do GIMP-a a plugin skończy działanie.\n")\
    +_(" --------------------------------------------------------------- \n")\
    +_("Plug-in file-name:\n")+whoiam,
    "Open active layer to Reshade, resize and return to GIMP - V 0.1",
    "MareroQ",
    "GPL",
    "2016",
    _("Reshade..."),
    "RGB*,GRAY*",
    [
        (PF_IMAGE, "image", "Input image", None),
        (PF_DRAWABLE, "filename", "Start exchange file", None),
        (PF_FILENAME, "ink", _("Lokalizacja reshade.exe: "), "C:\\Program Files\\Reshade 3.0\\reshade.exe"),
        (PF_DIRNAME, "outputFolder", _("Katalog do zapisu pliku tymczasowego:"), "C:/temp/"),
        (PF_RADIO, "format", ("Format pliku do zapisu :"), "png", (("PNG", "png"),("JPG", "jpg"),("TIFF", "tif"))),
        (PF_BOOL, "schel", _("Powrócić z Reshade do GIMP-a? "), True),
        (PF_BOOL, "resize_1", _("Dopasować płótno do warstw? "), True),		
        (PF_BOOL, "rem_1", _("Skasować plik tymczasowy? "), False),
		
    ],
    [],
    open_file_in_reshade,
    menu="<Image>/Layer/",
    domain=("Gimp_to_Reshade", locale_directory)
    )

main()
